You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by ag...@apache.org on 2012/09/27 19:25:30 UTC

ios commit: Various spelling & grammer fixes.

Updated Branches:
  refs/heads/master ca0cb8915 -> f3cc1058d


Various spelling & grammer fixes.


Project: http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/commit/f3cc1058
Tree: http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/tree/f3cc1058
Diff: http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/diff/f3cc1058

Branch: refs/heads/master
Commit: f3cc1058d7c1449dc6cb79059ff487a6bc9dfd2a
Parents: ca0cb89
Author: Josh Soref <js...@rim.com>
Authored: Fri Sep 7 11:10:27 2012 -0400
Committer: Andrew Grieve <ag...@chromium.org>
Committed: Thu Sep 27 13:19:04 2012 -0400

----------------------------------------------------------------------
 CordovaLib/Classes/CDVAccelerometer.m              |    8 ++--
 CordovaLib/Classes/CDVCamera.m                     |    5 +--
 CordovaLib/Classes/CDVCapture.m                    |    6 ++--
 CordovaLib/Classes/CDVContact.m                    |   27 +++++++--------
 CordovaLib/Classes/CDVContacts.h                   |    9 ++---
 CordovaLib/Classes/CDVContacts.m                   |    2 +-
 CordovaLib/Classes/CDVDevice.m                     |    2 +-
 CordovaLib/Classes/CDVFile.m                       |    4 +-
 CordovaLib/Classes/CDVFileTransfer.m               |    2 +-
 CordovaLib/Classes/CDVLocation.h                   |    2 +-
 CordovaLib/Classes/CDVReachability.h               |    3 +-
 CordovaLib/Classes/CDVReachability.m               |    5 +--
 CordovaLib/Classes/CDVSound.m                      |    2 +-
 CordovaLib/Classes/CDVViewController.m             |    2 +-
 CordovaLib/Classes/NSData+Base64.m                 |    4 +-
 CordovaLib/Classes/NSDictionary+Extensions.m       |    2 +-
 CordovaLib/CordovaLibApp/AppDelegate.m             |    2 +-
 CordovaLib/CordovaLibTests/CDVWebViewTest.h        |    2 +-
 FirstRun.md                                        |    2 +-
 LICENSE                                            |    2 +-
 RELEASENOTES.md                                    |   10 +++---
 .../project/__TESTING__/Classes/AppDelegate.m      |    2 +-
 bin/templates/project/www/js/index.js              |    2 +-
 .../project/www/spec/lib/jasmine-1.2.0/jasmine.js  |   16 ++++----
 guides/Cordova Plugin Upgrade Guide.md             |    2 +-
 25 files changed, 60 insertions(+), 65 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVAccelerometer.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVAccelerometer.m b/CordovaLib/Classes/CDVAccelerometer.m
index 9249c87..32471db 100644
--- a/CordovaLib/Classes/CDVAccelerometer.m
+++ b/CordovaLib/Classes/CDVAccelerometer.m
@@ -30,7 +30,7 @@
 // defaults to 10 msec
 #define kAccelerometerInterval 40
 // g constant: -9.81 m/s^2
-#define kGravitionalConstant -9.81
+#define kGravitationalConstant -9.81
 
 - (CDVAccelerometer*)init
 {
@@ -101,9 +101,9 @@
     // Create an acceleration object
     NSMutableDictionary* accelProps = [NSMutableDictionary dictionaryWithCapacity:4];
 
-    [accelProps setValue:[NSNumber numberWithDouble:x * kGravitionalConstant] forKey:@"x"];
-    [accelProps setValue:[NSNumber numberWithDouble:y * kGravitionalConstant] forKey:@"y"];
-    [accelProps setValue:[NSNumber numberWithDouble:z * kGravitionalConstant] forKey:@"z"];
+    [accelProps setValue:[NSNumber numberWithDouble:x * kGravitationalConstant] forKey:@"x"];
+    [accelProps setValue:[NSNumber numberWithDouble:y * kGravitationalConstant] forKey:@"y"];
+    [accelProps setValue:[NSNumber numberWithDouble:z * kGravitationalConstant] forKey:@"z"];
     [accelProps setValue:[NSNumber numberWithDouble:timestamp] forKey:@"timestamp"];
 
     result = [CDVPluginResult resultWithStatus:CDVCommandStatus_OK messageAsDictionary:accelProps];

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVCamera.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVCamera.m b/CordovaLib/Classes/CDVCamera.m
index 3cb5829..84fde0f 100644
--- a/CordovaLib/Classes/CDVCamera.m
+++ b/CordovaLib/Classes/CDVCamera.m
@@ -275,12 +275,11 @@ static NSSet* org_apache_cordova_validArrowDirections;
         }
 
         if (cameraPicker.returnType == DestinationTypeFileUri) {
-            // write to temp directory and reutrn URI
+            // write to temp directory and return URI
             // get the temp directory path
             NSString* docsPath = [NSTemporaryDirectory ()stringByStandardizingPath];
             NSError* err = nil;
-            NSFileManager* fileMgr = [[NSFileManager alloc] init]; // recommended by apple (vs [NSFileManager defaultManager]) to be theadsafe
-
+            NSFileManager* fileMgr = [[NSFileManager alloc] init]; // recommended by apple (vs [NSFileManager defaultManager]) to be threadsafe
             // generate unique file name
             NSString* filePath;
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVCapture.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVCapture.m b/CordovaLib/Classes/CDVCapture.m
index c90b75b..08c5006 100644
--- a/CordovaLib/Classes/CDVCapture.m
+++ b/CordovaLib/Classes/CDVCapture.m
@@ -173,7 +173,7 @@
         data = UIImageJPEGRepresentation(image, 0.5);
     }
 
-    // write to temp directory and reutrn URI
+    // write to temp directory and return URI
     NSString* docsPath = [NSTemporaryDirectory ()stringByStandardizingPath];  // use file system temporary directory
     NSError* err = nil;
     NSFileManager* fileMgr = [[NSFileManager alloc] init];
@@ -467,7 +467,7 @@
 
 /* Called when image/movie is finished recording.
  * Calls success or error code as appropriate
- * if successful, result  contains an array (with just one entry since can only get one image unless build own camera UI) of MediaFile object representating the image
+ * if successful, result  contains an array (with just one entry since can only get one image unless build own camera UI) of MediaFile object representing the image
  *      name
  *      fullPath
  *      type
@@ -808,7 +808,7 @@
 
 - (void)updateTime
 {
-    // update the label with the ellapsed time
+    // update the label with the elapsed time
     [self.timerLabel setText:[self formatTime:self.avRecorder.currentTime]];
 }
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVContact.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVContact.m b/CordovaLib/Classes/CDVContact.m
index bc4ba4e..356fd23 100644
--- a/CordovaLib/Classes/CDVContact.m
+++ b/CordovaLib/Classes/CDVContact.m
@@ -142,7 +142,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
             [NSNull null], kW3ContactFieldValue,
             [NSNull null], kW3ContactFieldPrimary,
             [NSNull null], kW3ContactFieldId,
-            [NSNumber numberWithInt:kABPersonOrganizationProperty], kW3ContactOrganizationName,      /* careful, name is used mulitple times*/
+            [NSNumber numberWithInt:kABPersonOrganizationProperty], kW3ContactOrganizationName,      /* careful, name is used multiple times*/
             nil];
     }
     return org_apache_cordova_contacts_W3CtoAB;
@@ -316,7 +316,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
         [self setValue:aDate != nil ? aDate:ms forProperty:kABPersonBirthdayProperty inRecord:person asUpdate:bUpdate];
     }
     // don't update creation date
-    // modifiction date will get updated when save
+    // modification date will get updated when save
     // anniversary is removed from W3C Contact api Dec 9, 2010 spec - don't waste time on it yet
 
     // kABPersonDateProperty
@@ -377,7 +377,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
  * aValue - the value to set into the address book (code checks for null or [NSNull null]
  * aProperty - AddressBook property ID
  * aRecord - the record to update
- * bUpdate - whether this is a possible update vs a new enry
+ * bUpdate - whether this is a possible update vs a new entry
  * RETURN
  *	true - property was set (or input value as null)
  *	false - property was not set
@@ -390,7 +390,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
     if (aValue && ![aValue isKindOfClass:[NSNull class]]) {
         if (bUpdate && ([aValue isKindOfClass:[NSString class]] && ([aValue length] == 0))) { // if updating, empty string means to delete
             aValue = NULL;
-        } // really only need to set if different - more efficient to just update value or compare and only set if necessay???
+        } // really only need to set if different - more efficient to just update value or compare and only set if necessary???
         bSuccess = ABRecordSetValue(aRecord, aProperty, (__bridge CFTypeRef)aValue, &error);
         if (!bSuccess) {
             NSLog(@"error setting %d property", aProperty);
@@ -456,7 +456,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
  * ABRecordRef  person - the record to set values into
  * BOOL bUpdate - whether or not to update date or set as new.
  *	When updating:
- *	  emtpy array indicates to remove entire property
+ *	  empty array indicates to remove entire property
  *	  empty string indicates to remove
  *    [NSNull null] do not modify (keep existing record value)
  * RETURNS
@@ -590,7 +590,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
  * ABRecordRef person - the record to set the values into
  * BOOL bUpdate - YES if this is an update to an existing record
  *	When updating:
- *	  emtpy array indicates to remove entire property
+ *	  empty array indicates to remove entire property
  *	  value/label == "" indicates to remove
  *    value/label == [NSNull null] do not modify (keep existing record value)
  * RETURN
@@ -758,8 +758,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
 + (NSString*)convertPropertyLabelToContactType:(NSString*)label
 {
     NSString* type = nil;
-
-    if (label != nil) { // improve effieciency......
+    if (label != nil) { // improve efficiency......
         if ([label isEqualToString:(NSString*)kABPersonPhoneMobileLabel]) {
             type = kW3ContactPhoneMobileLabel;
         } else if ([label isEqualToString:(NSString*)kABPersonPhoneHomeFAXLabel] ||
@@ -877,7 +876,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
         return nc;
     }
     if ([self.returnFields objectForKey:kW3ContactDisplayName]) {
-        // diplayname requested -  iOS doesn't have so return null
+        // displayname requested -  iOS doesn't have so return null
         [nc setObject:[NSNull null] forKey:kW3ContactDisplayName];
         // may overwrite below if requested ContactName and there are no values
     }
@@ -1061,7 +1060,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
             value = (__bridge_transfer NSString*)ABRecordCopyCompositeName(self.record);
             [newName setObject:(value != nil) ? value:[NSNull null] forKey:kW3ContactFormattedName];
         } else {
-            // W3CtoAB returns NSNumber for AB name properies, get intValue and cast to ABPropertyID)
+            // W3CtoAB returns NSNumber for AB name properties, get intValue and cast to ABPropertyID)
             value = (__bridge_transfer NSString*)ABRecordCopyValue(self.record, (ABPropertyID)[[[CDVContact defaultW3CtoAB] valueForKey:i] intValue]);
             [newName setObject:(value != nil) ? value:[NSNull null] forKey:(NSString*)i];
         }
@@ -1070,7 +1069,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
     return newName;
 }
 
-/* Create array of Dictionaris to match JavaScript ContactField object for simple multiValue properties phoneNumbers, emails
+/* Create array of Dictionaries to match JavaScript ContactField object for simple multiValue properties phoneNumbers, emails
  * Input: (NSString*) W3Contact Property name
  * type
  *		for phoneNumbers type is one of (work,home,other, mobile, fax, pager)
@@ -1126,7 +1125,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
     return valuesArray;
 }
 
-/* Create array of Dictionaris to match JavaScript ContactAddress object for addresses
+/* Create array of Dictionaries to match JavaScript ContactAddress object for addresses
  *  pref - not supported
  *  type - address type
  *	formatted  - formatted for mailing label (what about localization?)
@@ -1249,7 +1248,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
     return imArray;
 }
 
-/* Create array of Dictionaris to match JavaScript ContactOrganization object
+/* Create array of Dictionaries to match JavaScript ContactOrganization object
  *	pref - not supported in iOS
  *  type - not supported in iOS
  *  name
@@ -1676,7 +1675,7 @@ static NSDictionary* org_apache_cordova_contacts_defaultFields = nil;
 /* search for values within MultiValue Dictionary properties Address or IM property
  * IN:
  * (NSArray*) fields - the array of W3C field names to search within
- * (ABPropertyID) propId - the AddressBook property that returns a multivalue dictionaty
+ * (ABPropertyID) propId - the AddressBook property that returns a multivalue dictionary
  * (NSString*) testValue - the string to search for within the specified fields
  *
  */

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVContacts.h
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVContacts.h b/CordovaLib/Classes/CDVContacts.h
index 9851950..4cf7734 100644
--- a/CordovaLib/Classes/CDVContacts.h
+++ b/CordovaLib/Classes/CDVContacts.h
@@ -66,11 +66,11 @@
    property                 :(ABPropertyID)property identifier:(ABMultiValueIdentifier)identifierForValue;
 
 /*
- * search - searchs for contacts.  Only person records are currently supported.
+ * search - searches for contacts.  Only person records are currently supported.
  *
  * arguments:
  *  1: successcallback - this is the javascript function that will be called with the array of found contacts
- *  2:  errorCallback - optional javascript functiont to be called in the event of an error with an error code.
+ *  2:  errorCallback - optional javascript function to be called in the event of an error with an error code.
  * options:  dictionary containing ContactFields and ContactFindOptions
  *	fields - ContactFields array
  *  findOptions - ContactFindOptions object as dictionary
@@ -83,8 +83,7 @@
  *
  * arguments:
  *  1: success callback - this is the javascript function that will be called with the JSON representation of the saved contact
- *		search calls a fixed navigator.service.contacts._findCallback which then calls the succes callback stored before making the call into obj. c
- *
+ *		search calls a fixed navigator.service.contacts._findCallback which then calls the success callback stored before making the call into obj-c
  */
 - (void)save:(CDVInvokedUrlCommand*)command;
 
@@ -125,7 +124,7 @@
 @property (copy) NSString* callbackId;
 @end
 
-/* ABPersonViewController does not have any UI to dismiss.  Adding navigationItems to it does not work properly,  thenavigationItems are lost when the app goes into the background.
+/* ABPersonViewController does not have any UI to dismiss.  Adding navigationItems to it does not work properly,  the navigationItems are lost when the app goes into the background.
     The solution was to create an empty NavController in front of the ABPersonViewController. This
     causes the ABPersonViewController to have a back button. By subclassing the ABPersonViewController,
     we can override viewWillDisappear and take down the entire NavigationController at that time.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVContacts.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVContacts.m b/CordovaLib/Classes/CDVContacts.m
index dcab517..012a908 100644
--- a/CordovaLib/Classes/CDVContacts.m
+++ b/CordovaLib/Classes/CDVContacts.m
@@ -217,7 +217,7 @@ dispatch_queue_t workQueue = nil;
 
         [peoplePicker pushViewController:personController animated:YES];
     } else {
-        // Retreive and return pickedContact information
+        // Retrieve and return pickedContact information
         CDVContact* pickedContact = [[CDVContact alloc] initFromABRecord:(ABRecordRef)person];
         NSArray* fields = [picker.options objectForKey:@"fields"];
         NSDictionary* returnFields = [[CDVContact class] calcReturnFields:fields];

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVDevice.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVDevice.m b/CordovaLib/Classes/CDVDevice.m
index d6cc7e4..0b8f026 100644
--- a/CordovaLib/Classes/CDVDevice.m
+++ b/CordovaLib/Classes/CDVDevice.m
@@ -33,7 +33,7 @@
 
     /* Settings.plist
      * Read the optional Settings.plist file and push these user-defined settings down into the web application.
-     * This can be useful for supplying build-time configuration variables down to the app to change its behaviour,
+     * This can be useful for supplying build-time configuration variables down to the app to change its behavior,
      * such as specifying Full / Lite version, or localization (English vs German, for instance).
      */
     // TODO: turn this into an iOS only plugin

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVFile.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVFile.m b/CordovaLib/Classes/CDVFile.m
index 1334a3e..14cf61b 100644
--- a/CordovaLib/Classes/CDVFile.m
+++ b/CordovaLib/Classes/CDVFile.m
@@ -607,7 +607,7 @@ extern NSString * const NSURLIsExcludedFromBackupKey __attribute__((weak_import)
     [self writeJavascript:jsString];
 }
 
-/* recurvsively removes the directory
+/* recursively removes the directory
  * IN:
  * NSArray* arguments
  *	0 - NSString* fullPath
@@ -690,7 +690,7 @@ extern NSString * const NSURLIsExcludedFromBackupKey __attribute__((weak_import)
 }
 
 /**
- * Helpfer function to check to see if the user attempted to copy an entry into its parent without changing its name,
+ * Helper function to check to see if the user attempted to copy an entry into its parent without changing its name,
  * or attempted to copy a directory into a directory that it contains directly or indirectly.
  *
  * IN:

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVFileTransfer.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVFileTransfer.m b/CordovaLib/Classes/CDVFileTransfer.m
index c573642..5b4e75b 100644
--- a/CordovaLib/Classes/CDVFileTransfer.m
+++ b/CordovaLib/Classes/CDVFileTransfer.m
@@ -539,7 +539,7 @@ static CFIndex WriteDataToStream(NSData* data, CFWriteStreamRef stream)
 
 /* TESTING ONLY CODE
 // use ONLY for testing with self signed certificates
-// uncomment and modify server name in connectiondidReceiveAuthenticationChallenge
+// uncomment and modify server name in connection didReceiveAuthenticationChallenge
 - (BOOL)connection:(NSURLConnection *)connection canAuthenticateAgainstProtectionSpace:(NSURLProtectionSpace *)protectionSpace
 {
     return [protectionSpace.authenticationMethod isEqualToString:NSURLAuthenticationMethodServerTrust];

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVLocation.h
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVLocation.h b/CordovaLib/Classes/CDVLocation.h
index ae31557..7087d43 100644
--- a/CordovaLib/Classes/CDVLocation.h
+++ b/CordovaLib/Classes/CDVLocation.h
@@ -48,7 +48,7 @@ typedef NSUInteger CDVLocationStatus;
 
 @end
 
-// simple ojbect to keep track of location information
+// simple object to keep track of location information
 @interface CDVLocationData : NSObject {
     CDVLocationStatus locationStatus;
     NSMutableArray* locationCallbacks;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVReachability.h
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVReachability.h b/CordovaLib/Classes/CDVReachability.h
index 5d5f22f..01a95c3 100644
--- a/CordovaLib/Classes/CDVReachability.h
+++ b/CordovaLib/Classes/CDVReachability.h
@@ -1,8 +1,7 @@
 /*
 
  File: Reachability.h
- Abstract: Basic demonstration of how to use the SystemConfiguration Reachablity APIs.
-
+ Abstract: Basic demonstration of how to use the SystemConfiguration Reachability APIs.
  Version: 2.2
 
  Disclaimer: IMPORTANT:  This Apple software is supplied to you by Apple Inc.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVReachability.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVSound.m b/CordovaLib/Classes/CDVSound.m
index 37579bd..d283a5f 100644
--- a/CordovaLib/Classes/CDVSound.m
+++ b/CordovaLib/Classes/CDVSound.m
@@ -209,7 +209,7 @@
             bError = [self prepareToPlay:audioFile withId:mediaId];
         }
         if (!bError) {
-            // audioFile.player != nil  or player was sucessfully created
+            // audioFile.player != nil  or player was successfully created
             // get the audioSession and set the category to allow Playing when device is locked or ring/silent switch engaged
             if ([self hasAudioSession]) {
                 NSError* __autoreleasing err = nil;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVViewController.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/CDVViewController.m b/CordovaLib/Classes/CDVViewController.m
index 646818d..a0a29f0 100644
--- a/CordovaLib/Classes/CDVViewController.m
+++ b/CordovaLib/Classes/CDVViewController.m
@@ -576,7 +576,7 @@
     }
 
     /*
-     * all tel: scheme urls we let the UIWebview handle it using the default behaviour
+     * all tel: scheme urls we let the UIWebview handle it using the default behavior
      */
     else if ([[url scheme] isEqualToString:@"tel"]) {
         return YES;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/NSData+Base64.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/NSData+Base64.m b/CordovaLib/Classes/NSData+Base64.m
index 3083fa1..08c801b 100644
--- a/CordovaLib/Classes/NSData+Base64.m
+++ b/CordovaLib/Classes/NSData+Base64.m
@@ -64,7 +64,7 @@ static unsigned char cdvbase64DecodeLookup[256] =
 //	length - the length of the string or -1 (to specify strlen should be used)
 //	outputLength - if not-NULL, on output will contain the decoded length
 //
-// returns the decoded buffer. Must be free'd by caller. Length is given by
+// returns the decoded buffer. Must be freed by caller. Length is given by
 //	outputLength.
 //
 void *CDVNewBase64Decode(
@@ -130,7 +130,7 @@ void *CDVNewBase64Decode(
 //	outputLength - if not-NULL, on output will contain the encoded length
 //		(not including terminating 0 char)
 //
-// returns the encoded buffer. Must be free'd by caller. Length is given by
+// returns the encoded buffer. Must be freed by caller. Length is given by
 //	outputLength.
 //
 char *CDVNewBase64Encode(

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/NSDictionary+Extensions.m
----------------------------------------------------------------------
diff --git a/CordovaLib/Classes/NSDictionary+Extensions.m b/CordovaLib/Classes/NSDictionary+Extensions.m
index 4f05245..80e9ac1 100644
--- a/CordovaLib/Classes/NSDictionary+Extensions.m
+++ b/CordovaLib/Classes/NSDictionary+Extensions.m
@@ -69,7 +69,7 @@
  *	(BOOL*) bString - if exists will be set to YES if object is an NSString, NO if not
  *	(BOOL*) bNull - if exists will be set to YES if object is an NSNull, NO if not
  *	(BOOL*) bArray - if exists will be set to YES if object is an NSArray, NO if not
- *	(BOOL*) bNumber - if exsists will be set to YES if object is an NSNumber, NO if not
+ *	(BOOL*) bNumber - if exists will be set to YES if object is an NSNumber, NO if not
  *
  *	OUT:
  *	YES if key exists

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/CordovaLibApp/AppDelegate.m
----------------------------------------------------------------------
diff --git a/CordovaLib/CordovaLibApp/AppDelegate.m b/CordovaLib/CordovaLibApp/AppDelegate.m
index d47892d..77f681f 100644
--- a/CordovaLib/CordovaLibApp/AppDelegate.m
+++ b/CordovaLib/CordovaLibApp/AppDelegate.m
@@ -55,7 +55,7 @@
 
 - (void)destroyViewController
 {
-    // Clean up circular refs so that the view controller will actully be released.
+    // Clean up circular refs so that the view controller will actually be released.
     [self.viewController dispose];
     self.viewController = nil;
     self.window.rootViewController = nil;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/CordovaLibTests/CDVWebViewTest.h
----------------------------------------------------------------------
diff --git a/CordovaLib/CordovaLibTests/CDVWebViewTest.h b/CordovaLib/CordovaLibTests/CDVWebViewTest.h
index 4bb9b32..7bda31f 100644
--- a/CordovaLib/CordovaLibTests/CDVWebViewTest.h
+++ b/CordovaLib/CordovaLibTests/CDVWebViewTest.h
@@ -37,6 +37,6 @@
 // Runs the run loop until the given block returns true, or until a timeout
 // occurs.
 - (void)waitForConditionName:(NSString*)conditionName block:(BOOL (^)())block;
-// Convenince function for stringByEvaluatingJavaScriptFromString.
+// Convenience function for stringByEvaluatingJavaScriptFromString.
 - (NSString*)evalJs:(NSString*)code;
 @end

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/FirstRun.md
----------------------------------------------------------------------
diff --git a/FirstRun.md b/FirstRun.md
index ce6c7ef..eb866f3 100644
--- a/FirstRun.md
+++ b/FirstRun.md
@@ -52,7 +52,7 @@ Follow the instructions in the [**Command-Line Usage** section](http://docs.cord
 
 <br />
 
-That's it! Modify the contents of the "www" directory to add your HTML, CSS and Javascript.
+That's it! Modify the contents of the "www" directory to add your HTML, CSS and JavaScript.
 <br />
 
 ## Links

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/LICENSE
----------------------------------------------------------------------
diff --git a/LICENSE b/LICENSE
index 1abba1e..afb3f51 100644
--- a/LICENSE
+++ b/LICENSE
@@ -236,7 +236,7 @@
 
  /*
  File: CordovaLib/classes/Reachability.*
- Abstract: Basic demonstration of how to use the SystemConfiguration Reachablity APIs.
+ Abstract: Basic demonstration of how to use the SystemConfiguration Reachability APIs.
  
  Version: 2.2
  

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/RELEASENOTES.md
----------------------------------------------------------------------
diff --git a/RELEASENOTES.md b/RELEASENOTES.md
index 8b48e22..2f2d6a2 100644
--- a/RELEASENOTES.md
+++ b/RELEASENOTES.md
@@ -28,7 +28,7 @@ Cordova is a static library that enables developers to include the Cordova API i
 * [CB-274] iOS Cordova Template Project is not compilable with default Apple's ARC compiler 3.0
 * [CB-593] Click and touch events do not fire after using scroll CSS
 * [CB-675] Allow multiple versions of PhoneGap to be installed in Xcode (added bin/update_cordova_subproject script)
-* [CB-828] iOS contact.save() stucks the UI from updating on heavy load & has memory leaks.
+* [CB-828] iOS contact.save() stops the UI from updating on heavy load & has memory leaks.
 * [CB-903] iOS 6 - add setting to set WebKitStoreWebDataForBackup for user defaults from Cordova.plist/config.xml
 * [CB-904] iOS 6 - turn off CDVLocalStorage core plugin when on iOS 6
 * [CB-994] CDVLocalStorage core plugin does not fully backup when app setting "Application does not run in background" is YES
@@ -75,7 +75,7 @@ Cordova is a static library that enables developers to include the Cordova API i
 * Add a benchmark into CordovaLibApp for measuring exec() speed.
 * Added Echo plugin (for benchmarking) into CordovaLib
 * Support JS->Native messages via an XHR & URL Protocol see [CB-593]
-* Refactor peoplePickerNavigationControllerDidCancel, always return dictionnary with id kABRecordInvalidID.
+* Refactor peoplePickerNavigationControllerDidCancel, always return dictionary with id kABRecordInvalidID.
 * Deployment target for CordovaLib was not updated to 4.2 (we changed it in the template, but not the lib)
 * Fixed null dereference in FileTransfer upload when URL is invalid.
 
@@ -239,7 +239,7 @@ Cordova is a static library that enables developers to include the Cordova API i
 * Added unification of accelerometer values on ios (based on android values)
 * Removed old JS, added cordova-js version
 * Changes to CordovaLib makefile for generating JS
-* Fixed CB-260: Can't install Phonegap with new Xcode 4.3
+* Fixed CB-260: Can't install PhoneGap with new Xcode 4.3
 * Fixed Xcode app detection (using Spotlight) in Makefile
 * Fixed CB-306 - Remove extra template App delegate methods
 * Fixes CB-255 - iOS: a parameter with value 'null' is not passed to 'arguments' array
@@ -394,7 +394,7 @@ Removed GetFunctionName.js (unused)
 * usage of VERIFY_ARGUMENTS macro in File plugin - related to #244
 * fixed #259: PluginResult toJSONString does not quote strings in arrays
 * added ability so that unhanded URLs (i.e. custom schemes in a web-page) will notify PhoneGap plugins of this custom url so that the plugins can handle it themselves. This would give the ability to handle callbacks for OAuth logins (Twitter/Facebook) in the main PhoneGap UIWebview, and not require the ChildBrowser plugin.
-* fixes #263 Phone call - tel: scheme handling hides default behaviour
+* fixes #263 Phone call - tel: scheme handling hides default behavior
 * fixes #269 - Add Obj-C unit-tests for whitelist implementation
 * fixed #256 PhoneGapDelegate (UIApplicationDelegate) property hides new property in iOS 5
 * fixed #254 Prefix the SBJSON classes included in PhoneGap with 'PG'
@@ -508,7 +508,7 @@ Removed GetFunctionName.js (unused)
   
 * phonegap.js is minified using the YUI compressor, and also renamed to phonegap.{ver}.min.js where {ver} is the version number of PhoneGapLib from the VERSION file 
 * the PhoneGap template is changed as well, at build time it will replace any references to 'src="phonegap.js"' to the new versioned js file (and copy the new phonegap.{ver}.min.js file). This replacement will look in all files in the 'www' folder. 
-* note that with the new PhoneGapLib phonegap.{ver}.min.js renaming, existing PhoneGap templates must copy the new "Copy PhoneGap Javascript" post-build script from the new template (in Xcode, under Targets/[ProjectName]) 
+* note that with the new PhoneGapLib phonegap.{ver}.min.js renaming, existing PhoneGap templates must copy the new "Copy PhoneGap JavaScript" post-build script from the new template (in Xcode, under Targets/[ProjectName]) 
 
 <br />
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/bin/templates/project/__TESTING__/Classes/AppDelegate.m
----------------------------------------------------------------------
diff --git a/bin/templates/project/__TESTING__/Classes/AppDelegate.m b/bin/templates/project/__TESTING__/Classes/AppDelegate.m
index 5803726..35a1076 100644
--- a/bin/templates/project/__TESTING__/Classes/AppDelegate.m
+++ b/bin/templates/project/__TESTING__/Classes/AppDelegate.m
@@ -131,7 +131,7 @@
 
 - (NSUInteger)application:(UIApplication*)application supportedInterfaceOrientationsForWindow:(UIWindow*)window
 {
-    // IPhone doesn't support upside down by default, while the IPad does.  Override to allow all orientations always, and let the root view controller decide whats allowed (the supported orientations mask gets intersected).
+    // iPhone doesn't support upside down by default, while the iPad does.  Override to allow all orientations always, and let the root view controller decide what's allowed (the supported orientations mask gets intersected).
     NSUInteger supportedInterfaceOrientations = (1 << UIInterfaceOrientationPortrait) | (1 << UIInterfaceOrientationLandscapeLeft) | (1 << UIInterfaceOrientationLandscapeRight) | (1 << UIInterfaceOrientationPortraitUpsideDown);
 
     return supportedInterfaceOrientations;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/bin/templates/project/www/js/index.js
----------------------------------------------------------------------
diff --git a/bin/templates/project/www/js/index.js b/bin/templates/project/www/js/index.js
index 3b75d3f..bf02e98 100644
--- a/bin/templates/project/www/js/index.js
+++ b/bin/templates/project/www/js/index.js
@@ -31,7 +31,7 @@ var app = {
     // deviceready Event Handler
     //
     // The scope of `this` is the event. In order to call the `receivedEvent`
-    // function, we must explicity call `app.receivedEvent(...);`
+    // function, we must explicitly call `app.receivedEvent(...);`
     onDeviceReady: function() {
         app.receivedEvent('deviceready');
     },

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/bin/templates/project/www/spec/lib/jasmine-1.2.0/jasmine.js
----------------------------------------------------------------------
diff --git a/bin/templates/project/www/spec/lib/jasmine-1.2.0/jasmine.js b/bin/templates/project/www/spec/lib/jasmine-1.2.0/jasmine.js
index 03bf89a..a6ed0f5 100644
--- a/bin/templates/project/www/spec/lib/jasmine-1.2.0/jasmine.js
+++ b/bin/templates/project/www/spec/lib/jasmine-1.2.0/jasmine.js
@@ -161,7 +161,7 @@ jasmine.isA_ = function(typeName, value) {
 };
 
 /**
- * Pretty printer for expecations.  Takes any object and turns it into a human-readable string.
+ * Pretty printer for exceptions.  Takes any object and turns it into a human-readable string.
  *
  * @param value {Object} an object to be outputted
  * @returns {String}
@@ -183,7 +183,7 @@ jasmine.isDomNode = function(obj) {
 };
 
 /**
- * Returns a matchable 'generic' object of the class type.  For use in expecations of type when values don't matter.
+ * Returns a matchable 'generic' object of the class type.  For use in exceptions of type when values don't matter.
  *
  * @example
  * // don't care about which function is passed in, as long as it's a function
@@ -212,7 +212,7 @@ jasmine.objectContaining = function (sample) {
 };
 
 /**
- * Jasmine Spies are test doubles that can act as stubs, spies, fakes or when used in an expecation, mocks.
+ * Jasmine Spies are test doubles that can act as stubs, spies, fakes or when used in an exception, mocks.
  *
  * Spies should be created in test setup, before expectations.  They can then be checked, using the standard Jasmine
  * expectation syntax. Spies can be checked if they were called or not and what the calling params were.
@@ -293,7 +293,7 @@ jasmine.Spy = function(name) {
 };
 
 /**
- * Tells a spy to call through to the actual implemenatation.
+ * Tells a spy to call through to the actual implementation.
  *
  * @example
  * var foo = {
@@ -356,7 +356,7 @@ jasmine.Spy.prototype.andThrow = function(exceptionMsg) {
  * // defining a spy from scratch: foo() calls the function baz
  * var foo = jasmine.createSpy('spy on foo').andCall(baz);
  *
- * // defining a spy on an existing property: foo.bar() calls an anonymnous function
+ * // defining a spy on an existing property: foo.bar() calls an anonymous function
  * spyOn(foo, 'bar').andCall(function() { return 'baz';} );
  *
  * @param {Function} fakeFunc
@@ -515,7 +515,7 @@ var expect = function(actual) {
 if (isCommonJS) exports.expect = expect;
 
 /**
- * Defines part of a jasmine spec.  Used in cominbination with waits or waitsFor in asynchrnous specs.
+ * Defines part of a jasmine spec.  Used in combination with waits or waitsFor in asynchronous specs.
  *
  * @param {Function} func Function that defines part of a jasmine spec.
  */
@@ -1282,7 +1282,7 @@ jasmine.Matchers.prototype.toBeNull = function() {
 };
 
 /**
- * Matcher that boolean not-nots the actual.
+ * Matcher that boolean double-negates the actual.
  */
 jasmine.Matchers.prototype.toBeTruthy = function() {
   return !!this.actual;
@@ -1290,7 +1290,7 @@ jasmine.Matchers.prototype.toBeTruthy = function() {
 
 
 /**
- * Matcher that boolean nots the actual.
+ * Matcher that boolean negates the actual.
  */
 jasmine.Matchers.prototype.toBeFalsy = function() {
   return !this.actual;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/guides/Cordova Plugin Upgrade Guide.md
----------------------------------------------------------------------
diff --git a/guides/Cordova Plugin Upgrade Guide.md b/guides/Cordova Plugin Upgrade Guide.md
index d31f8a5..ddf44a8 100644
--- a/guides/Cordova Plugin Upgrade Guide.md	
+++ b/guides/Cordova Plugin Upgrade Guide.md	
@@ -90,7 +90,7 @@ This document is for developers who need to upgrade their Cordova  plugins to a
 1. **Install** Cordova 1.6.x
 2. Follow the **"Upgrading older Cordova plugins to 1.5.0"** section, if necessary
 3. See the **1.6.0 Plugin Notes** section for new functionality available to plugins
-4. The global **"Cordova"** (upper-case C) was renamed to **"cordova"** (lower-case c) to match the cordova-js Android implementation in 1.5.0 that is now common to Android, Blackberry and iOS. Please rename your calls to reflect the new lower-case **c**, or you can add a shim (which will support older versions) like so:
+4. The global **"Cordova"** (upper-case C) was renamed to **"cordova"** (lower-case c) to match the cordova-js Android implementation in 1.5.0 that is now common to Android, BlackBerry and iOS. Please rename your calls to reflect the new lower-case **c**, or you can add a shim (which will support older versions) like so:
 
     a. Wrap your plugin JavaScript in a temporary scope (self-executing function) - see ["Temporary Scope"](http://ejohn.org/apps/learn/#57) or [this](https://github.com/phonegap/phonegap-plugins/wiki/Wrapping-your-Plugin's-JavaScript)
diff --git a/CordovaLib/Classes/CDVReachability.m b/CordovaLib/Classes/CDVReachability.m
index ec05595..3c5a48b 100644
--- a/CordovaLib/Classes/CDVReachability.m
+++ b/CordovaLib/Classes/CDVReachability.m
@@ -1,8 +1,7 @@
 /*
 
  File: Reachability.m
- Abstract: Basic demonstration of how to use the SystemConfiguration Reachablity APIs.
-
+ Abstract: Basic demonstration of how to use the SystemConfiguration Reachability APIs.
  Version: 2.2
 
  Disclaimer: IMPORTANT:  This Apple software is supplied to you by Apple Inc.
@@ -97,7 +96,7 @@ static void CDVReachabilityCallback(SCNetworkReachabilityRef target, SCNetworkRe
     }
 
     // We're on the main RunLoop, so an NSAutoreleasePool is not necessary, but is added defensively
     // in case someon uses the Reachablity object in a different thread.
     @autoreleasepool {
         CDVReachability* noteObject = (__bridge CDVReachability*)info;
         // Post a notification to notify the client that the network reachability changed.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-ios/blob/f3cc1058/CordovaLib/Classes/CDVSound.m
----------------------------------------------------------------------
@@ -97,7 +96,7 @@ static void CDVReachabilityCallback(SCNetworkReachabilityRef target, SCNetworkRe
 
     // We're on the main RunLoop, so an NSAutoreleasePool is not necessary, but is added defensively
-    // in case someon uses the Reachablity object in a different thread.
+    // in case someon uses the Reachability object in a different thread.
     @autoreleasepool {
         CDVReachability* noteObject = (__bridge CDVReachability*)info;